# Changelog

## 0.0.3 (2025-12-26)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/y2-intel/y2-py/compare/v0.0.2...v0.0.3)

### Chores

* update SDK settings ([86d94f7](https://github.com/y2-intel/y2-py/commit/86d94f730719ad9c2be47e1c1fde598fb88eebc2))

## 0.0.2 (2025-12-24)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/y2-intel/y2-py/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([199b21a](https://github.com/y2-intel/y2-py/commit/199b21aa7a34f9a5489fa593a764afa8c7097248))
* update SDK settings ([9d60021](https://github.com/y2-intel/y2-py/commit/9d600214561cf0b69254a5b20783bef26ee6f34f))
